#
# spec file for package libntlm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libntlm
%define lname	libntlm0
Version:        1.8
Release:        1.2
Summary:        Implementation of Microsoft's NTLMv1 authentication
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://gitlab.com/gsasl/libntlm/
#Git-Clone:	https://gitlab.com/gsasl/libntlm.git
#DL-URL:	https://download.savannah.nongnu.org/releases/libntlm/
Source:         https://download.savannah.nongnu.org/releases/libntlm/%name-%version.tar.gz
Source2:        https://download.savannah.nongnu.org/releases/libntlm/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRequires:  pkg-config

%description
Libntlm provides routines to manipulate the structures used for the
client end of Microsoft NTLMv1 authentication.

%package -n %lname
Summary:        Implementation of Microsoft's NTLMv1 authentication
Group:          System/Libraries

%description -n %lname
Libntlm provides routines to manipulate the structures used for the
client end of Microsoft NTLMv1 authentication.

%package devel
Summary:        Development files for libntlm, an NTLMv1 authentication library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Libntlm provides routines to manipulate the structures used for the
client end of Microsoft NTLMv1 authentication.

This subpackage contains libraries and header files for developing
applications that want to make use of libntlm.

%prep
%autosetup -p1

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%check
make check

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING
%_libdir/libntlm.so.0*

%files devel
%doc ChangeLog NEWS README
%_includedir/ntlm.h
%_libdir/libntlm.so
%_libdir/pkgconfig/libntlm.pc

%changelog
* Sun Aug 18 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8:
  * The release tarball is now reproducible.
  * We publish a minimal source-only tarball.
  * This tarball does not contain any generated files, and is
    sufficient to reproduce the full tarball
    (assuming build dependencies are available).
  * No changes since last version.
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.7:
  * Moved GitLab URL to <https://gitlab.com/gsasl/libntlm>.
  * Use gnulib ./bootstrap for building from version
    controlled sources.
  * API and ABI modifications:
    + No changes since last version.
* Mon May 22 2023 Frederic Crozat <fcrozat@suse.com>
- Update url and download locations for tarball.
* Tue Jun  9 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6
  * Fix buffer overflow in buildSmbNtlmAuth* function.
    CVE-2019-17455. [boo#1153669]
* Thu Aug 22 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.5
  * Build system fixes, patches for LTO/gcc8 support.
* Tue Oct 27 2015 meissner@suse.com
- run "make test"
* Wed Jul 17 2013 jengelh@inai.de
- Update to new upstream release 1.4
  * Fixes to the build procedure and autotools update. No
  user visible changes.
- Optional signature verification
* Tue Jun 19 2012 jengelh@inai.de
- Make package build on SLE_11 as well: use classic make install.
* Fri Nov 25 2011 jengelh@medozas.de
- Initial package (1.3) for build.opensuse.org
